@@ -1,9 +1,3 @@
-"""
-.. testsetup::
-
-    from compas.geometry import Point
-
-"""
 from __future__ import print_function
 from __future__ import absolute_import
 from __future__ import division
@@ -32,9 +26,6 @@ from compas.geometry.primitives import Primitive
 from compas.geometry.primitives import Vector
 
 
-__all__ = ['Point']
-
-
 class Point(Primitive):
     """A point is defined by XYZ coordinates.
 
@@ -116,17 +107,6 @@ class Point(Primitive):
     Point(100.000, 196.000, 324.000)
     """
 
-    __slots__ = ['_x', '_y', '_z']
-
-    def __init__(self, x, y, z=0.0):
-        super(Point, self).__init__()
-        self._x = 0.0
-        self._y = 0.0
-        self._z = 0.0
-        self.x = x
-        self.y = y
-        self.z = z
-
     @property
     def DATASCHEMA(self):
         from schema import Schema
@@ -134,18 +114,19 @@ class Point(Primitive):
         return Schema(is_float3)
 
     @property
-    def JSONSCHEMA(self):
-        from compas import versionstring
-        schema = {
-            "$schema": "http://json-schema.org/draft-07/schema#",
-            "$id": "https://github.com/compas-dev/compas/schemas/point.json",
-            "$compas": versionstring,
-            "type": "array",
-            "minItems": 3,
-            "maxItems": 3,
-            "items": {"type": "number"}
-        }
-        return schema
+    def JSONSCHEMANAME(self):
+        return 'point'
+
+    __slots__ = ['_x', '_y', '_z']
+
+    def __init__(self, x, y, z=0.0, **kwargs):
+        super(Point, self).__init__(**kwargs)
+        self._x = 0.0
+        self._y = 0.0
+        self._z = 0.0
+        self.x = x
+        self.y = y
+        self.z = z
 
     @property
     def data(self):
